@@ -624,6 +624,8 @@ __realize (GtkWidget *widget)
   GdkWindowAttr attributes;
   gint attributes_mask = 0;
 
+  GTK_WIDGET_CLASS (ssw_xpaned_parent_class)->realize (widget);
+
   window = gtk_widget_get_parent_window (widget);
   gtk_widget_set_window (widget, window);
 
@@ -657,10 +659,14 @@ __unrealize (GtkWidget *widget)
 {
   SswXpaned *xpaned = SSW_XPANED (widget);
 
+  GTK_WIDGET_CLASS (ssw_xpaned_parent_class)->unrealize (widget);
+
   g_object_unref (xpaned->cursor);
 
-  gtk_widget_unregister_window (GTK_WIDGET (xpaned), xpaned->handle);
+  gtk_widget_unregister_window (widget, xpaned->handle);
   gdk_window_destroy (xpaned->handle);
+  xpaned->handle = NULL;
+  gtk_widget_set_realized (widget, FALSE);
 }
 
 
